@@ -22,8 +22,7 @@ class DataSet:
     qp_data = None
     tally = None
 
-    def __init__(self, name=None, api_key=None, host='tally.datasmoothie.com/', ssl=True):
-        self._name = name
+    def __init__(self, api_key=None, host='tally.datasmoothie.com/', ssl=True):
         self.add_credentials(api_key=api_key, host=host, ssl=ssl)
 
     def add_credentials(self, api_key=None, host='tally.datasmoothie.com/', ssl=True):
@@ -54,6 +53,34 @@ class DataSet:
         self.qp_data = pd.read_csv(data_csv).to_csv()
         self.dataset_type = 'quantipy'
 
+    def use_csv(self, csv_file):
+        csv = pd.read_csv(csv_file).to_csv()
+        payload = {'csv': csv}
+        response = self.tally.post_request('tally', 'convert_data_to_csv_json', payload)
+        result = json.loads(response.content)
+        self.qp_meta = json.dumps(result['json'])
+        self.qp_data = result['csv']
+        self.dataset_type = 'quantipy'
+
+    def use_confirmit(self, source_projectid, source_idp_url, source_client_id, source_client_secret, source_public_url):
+        payload = {
+            'datasource': {
+                'type': 'Confirmit',
+                'source_idp_url' : source_idp_url,
+                'source_projectid': source_projectid,
+                'source_client_id' : source_client_id,
+                'source_client_secret' : source_client_secret,
+                'source_public_site_url' : source_public_url
+            },
+        }
+        response = self.tally.post_request('tally', 'convert_data_to_csv_json', payload)
+        result = json.loads(response.content)
+        import pdb; pdb.set_trace()
+        self.qp_meta = json.dumps(result['json'])
+        self.qp_data = result['csv']
+        self.dataset_type = 'quantipy'
+
+
     def prepare_post_params(self, data_params, params={}):
         # initialise the payload with our chosen data
         if 'binary_data' in data_params:
@@ -75,7 +102,8 @@ class DataSet:
             df = Tally.result_to_dataframe(json_dict['result'])
             return df
         else:
-            raise ValueError
+            print(response.content)
+            raise ValueError(response.content)
 
     @add_data
     def convert_spss_to_csv_json(self, data_params=None):
